#!/usr/bin/python3

USR = "usr"
BIN = "bin"
EXEC_FILE = "file.exe"
WIN32 = "win32"
EXEC_DSC = "{0} {1}"
EXEC_MIMETYPE = "{0} --mime-type {1}"
PATH = "PATH"
POSIX_FILE = "file"